class ltsp::client::plymouth::logocta {

    file {
        "/opt/ltsp/i386/lib/plymouth/themes/ubuntu-logo/ubuntu_logo.png":
         mode    => 644,
         owner   => root,
         group   => root,
         source  => "puppet:///login_themes/plymouth/ubuntu_logo.png",
         notify  => Exec["ltsp_client_set_logo_en_plymouth"];
        "/opt/ltsp/i386/lib/plymouth/themes/ubuntu-logo/ubuntu_logo16.png":
         mode    => 644,
         owner   => root,
         group   => root,
         source  => "puppet:///login_themes/plymouth/ubuntu_logo16.png",
         notify  => Exec["ltsp_client_set_logo_en_plymouth"];
    }

    exec { "ltsp_client_set_logo_en_plymouth":
        command     => "chroot /opt/ltsp/i386/ update-initramfs -u",
        path        => "/bin:/sbin:/usr/sbin:/usr/bin",
        refreshonly => true,
        notify      => [ Exec["ltsp-update-image"], Exec["ltsp-update-kernels"] ],
        before      => [ Exec["ltsp-update-image"], Exec["ltsp-update-kernels"] ],
    }
}

class ltsp::client::ldm::carpani_cta {

    file {
        "/opt/ltsp/i386/usr/share/ldm/themes/ldm-carpani-cta":
         ensure  => directory,
         mode    => 644,
         owner   => root,
         group   => root,
         source  => "puppet:///ltsp/ldm-carpani-cta/",
         recurse => "true",
         notify  => Exec["set_ldm_theme_to_carpani_cta"],
         before  => [ Exec["set_ldm_theme_to_carpani_cta"]  ],
    }

   exec { "set_ldm_theme_to_carpani_cta":
       command => "chroot /opt/ltsp/i386/ update-alternatives --install /usr/share/ldm/themes/default ldm-theme /usr/share/ldm/themes/ldm-carpani-cta 100 && chroot /opt/ltsp/i386/  update-alternatives --auto ldm-theme",
       path    => "/bin:/sbin:/usr/sbin:/usr/bin",
       unless  => "chroot /opt/ltsp/i386/ update-alternatives --query ldm-theme | grep \"Value: /usr/share/ldm/themes/ldm-carpani-cta\"",
       notify  => Exec["ltsp-update-image"],
       before  => [ Exec["ltsp-update-image"] ],
   }
}

class ltsp::client::checkoutinroot {

    svn::checkout { ltsp-client:
       repository => "https://svn.redcta.org.ar/proyectos/redcta/trunk/ltsp-cliente",
       local_path => "/opt/ltsp/i386",
       local_name => "root",
       notify     => Exec["ltsp-update-image"],
       before     => [ Exec["ltsp-update-image"]  ],
    }
}

define ltsp::client::debproxy::activateclient ( $debproxyhost ) { 

    file { 
        "/opt/ltsp/i386/etc/apt/apt.conf.d/01proxy":
         ensure  => "present",
         content => "Acquire::http { Proxy \"http://$debproxyhost:3142\"; };\n",
         before  => [ Exec["ltsp-update-image"] ],
         notify  => Exec["ltsp-update-image"],
    }
}

class ltsp::client::localgen::es_AR {

    exec { "localgen_es_AR":
        command => "chroot /opt/ltsp/i386/ locale-gen es_AR.UTF-8",
        path    => "/bin:/sbin:/usr/sbin:/usr/bin",
        unless  => "chroot /opt/ltsp/i386/ grep es_AR.UTF-8 /var/lib/locales/supported.d/local",
        notify  => Exec["ltsp-update-image"],
        before  => [ Exec["ltsp-update-image"] ],
    }
}


class ltsp::client::installpackages {

    define ltsp_client_installpackages($packages) {
       ltsp_client_installpackage { $packages: package => $name }
    }
 
    define ltsp_client_installpackage($package) {
        exec { "ltsp_client_install_$name":
            command => "chroot ${package} apt-get -y install $name",
            path    => "/bin:/sbin:/usr/sbin:/usr/bin",
            unless  => "chroot ${package} dpkg --get-selections $name | grep install",
            notify  => Exec["ltsp-update-image"],
            before  => [ Exec["ltsp-update-image"] ],
        }
    }

    ltsp_client_installpackages { 
        "/opt/ltsp/i386/": packages => [ "openssh-server", "iftop", "iotop", "screen", "ocsinventory-agent" ],
    }

    include ltsp::client::ocsinventory_agent
}


class ltsp::client::resolvsh {

   # bug en ltsp de ubuntu 9.04
   # https://bugs.launchpad.net/ubuntu/+source/ltsp/+bug/347957
   file { 
     "/opt/ltsp/i386/etc/init.d/chmod-resolv.sh":
      owner => root,
      group => root,
      mode => 755,
      source => "puppet:///ltsp/etc/chmod-resolv.sh";
   }
}

class ltsp::client::ocsinventory_agent {

   file {
    "/opt/ltsp/i386/etc/ocsinventory":
       ensure => directory,
       owner => "root", group => "root", mode => "755";
     "/opt/ltsp/i386/etc/ocsinventory/ocsinventory-agent.cfg":
      owner => root,
      group => root,
      mode => 600,
      source => "puppet:///ltsp/etc/ocsinventory/ocsinventory-agent.cfg";
   }
}

# cambia el formato de como se nombran las terminales
# en el chroot, update-initramfs -u 
# actulizar el kernel a fuera del chroot, ltsp-update-kernels 
# agregar en el /var/lib/tftpboot/lts.conf
# HOSTNAME_BASE = CTA-
# HOSTNAME_EXTRA = mac

class ltsp::client::hostname::cta {

   file {
     "/opt/ltsp/i386/usr/share/initramfs-tools/scripts/nfs-bottom/ltsp":
      owner => root,
      group => root,
      mode => 755,
      source => "puppet:///ltsp/ltsp";
   }
}


